@@ -50,7 +50,6 @@ package com.openexchange.admin.console.context;
 
 import java.rmi.Naming;
 import java.util.ArrayList;
-
 import com.openexchange.admin.console.AdminParser;
 import com.openexchange.admin.console.AdminParser.NeededQuadState;
 import com.openexchange.admin.console.user.UserAbstraction;
@@ -84,7 +83,7 @@ public class GetModuleAccess extends ContextAbstraction {
             final OXContextInterface oxres = (OXContextInterface) Naming.lookup(RMI_HOSTNAME +OXContextInterface.RMI_NAME);
 
             // Fetch access object
-            UserModuleAccess access = oxres.getModuleAccess(ctx, auth);
+            final UserModuleAccess access = oxres.getModuleAccess(ctx, auth);
             
             // output access object
             doCsvOutput(access);   
@@ -96,7 +95,7 @@ public class GetModuleAccess extends ContextAbstraction {
         }
     }
 
-    private void doCsvOutput(UserModuleAccess access) throws InvalidDataException {
+    private void doCsvOutput(final UserModuleAccess access) throws InvalidDataException {
         final ArrayList<ArrayList<String>> data = new ArrayList<ArrayList<String>>();
         final ArrayList<String> datarow = new ArrayList<String>();
         datarow.add(String.valueOf(access.getCalendar()));
@@ -124,12 +123,14 @@ public class GetModuleAccess extends ContextAbstraction {
         datarow.add(String.valueOf(access.isSubscription()));
         datarow.add(String.valueOf(access.isActiveSync()));
         datarow.add(String.valueOf(access.isUSM()));
+        datarow.add(String.valueOf(access.isGlobalAddressBookDisabled()));
+        datarow.add(String.valueOf(access.isPublicFolderEditable()));
         data.add(datarow);
         doCSVOutput(getAccessColums(),data);        
     }
 
     private static ArrayList<String> getAccessColums() {
-        final ArrayList<String> columnnames = new ArrayList<String>();
+        final ArrayList<String> columnnames = new ArrayList<String>(32);
         columnnames.add(UserAbstraction.OPT_ACCESS_CALENDAR);
         columnnames.add(UserAbstraction.OPT_ACCESS_CONTACTS);
         columnnames.add(UserAbstraction.OPT_ACCESS_DELEGATE_TASKS);
@@ -151,10 +152,14 @@ public class GetModuleAccess extends ContextAbstraction {
         columnnames.add(UserAbstraction.OPT_ACCESS_EDIT_GROUP);
         columnnames.add(UserAbstraction.OPT_ACCESS_EDIT_RESOURCE);
         columnnames.add(UserAbstraction.OPT_ACCESS_EDIT_PASSWORD);
+        columnnames.add(UserAbstraction.OPT_ACCESS_COLLECT_EMAIL_ADDRESSES);
+        columnnames.add(UserAbstraction.OPT_ACCESS_MULTIPLE_MAIL_ACCOUNTS);
         columnnames.add(UserAbstraction.OPT_ACCESS_PUBLICATION);
         columnnames.add(UserAbstraction.OPT_ACCESS_SUBSCRIPTION);
         columnnames.add(UserAbstraction.OPT_ACCESS_ACTIVE_SYNC);
         columnnames.add(UserAbstraction.OPT_ACCESS_USM);
+        columnnames.add(UserAbstraction.OPT_DISABLE_GAB);
+        columnnames.add(UserAbstraction.OPT_ACCESS_PUBLIC_FOLDER_EDITABLE);
         return columnnames;
     }
 
